==> lam_6.3.2.orig.tar.gz: lam-6.3.2/share/mpi/getprocname.c <==
/*
 *
 * Copyright 1998-1999, University of Notre Dame.
 * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
 *          and Andrew Lumsdaine
 *
 * This file is part of the Notre Dame LAM implementation of MPI.
 *
 * You should have received a copy of the License Agreement for the
 * Notre Dame LAM implementation of MPI along with the software; see
 * the file LICENSE.  If not, contact Office of Research, University
 * of Notre Dame, Notre Dame, IN 46556.
 *
 * Permission to modify the code and to distribute modified code is
 * granted, provided the text of this NOTICE is retained, a notice that
 * the code was modified is included with the above COPYRIGHT NOTICE and
 * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
 * file is distributed with the modified code.
 *
 * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
 * By way of example, but not limitation, Licensor MAKES NO
 * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
 * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
 * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
 * OR OTHER RIGHTS.  
 *
 * Additional copyrights may follow.
 *
 *	Ohio Trollius
 *	Copyright 1996 The Ohio State University
 *	RBD
 *
 *	$Id: getprocname.c,v 6.2 1999/05/25 22:07:54 kmeyer1 Exp $
 *
 *	Function:	- get the host name
 *	Accepts:	- name buffer (returned value)
 *			- ptr name length (returned value)
 *	Returns:	- MPI_SUCCESS or error code
 */

#include <string.h>

#include <blktype.h>
#include <mpi.h>
#include <mpisys.h>
#include <terror.h>

extern int		gethostname();


int
MPI_Get_processor_name(name, len)

char			*name;
int			*len;

{
	lam_initerr();
	lam_setfunc(BLKMPIGETPNAME);

	if (gethostname(name, MPI_MAX_PROCESSOR_NAME - 1)) {
		return(lam_errfunc(MPI_COMM_WORLD, BLKMPIGETPNAME,
				lam_mkerr(MPI_ERR_OTHER, errno)));
	} else {
		name[MPI_MAX_PROCESSOR_NAME - 1] = '\0';
		*len = strlen(name);
	}

	lam_resetfunc(BLKMPIGETPNAME);
	return(MPI_SUCCESS);
}

==> lam-6.5.1.tar.gz: lam-6.5.1/share/mpi/getprocname.c <==
/*
 * Copyright 1998-2001, University of Notre Dame.
 * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
 *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
 * 
 * This file is part of the Notre Dame LAM implementation of MPI.
 * 
 * You should have received a copy of the License Agreement for the Notre
 * Dame LAM implementation of MPI along with the software; see the file
 * LICENSE.  If not, contact Office of Research, University of Notre
 * Dame, Notre Dame, IN 46556.
 * 
 * Permission to modify the code and to distribute modified code is
 * granted, provided the text of this NOTICE is retained, a notice that
 * the code was modified is included with the above COPYRIGHT NOTICE and
 * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
 * file is distributed with the modified code.
 * 
 * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
 * By way of example, but not limitation, Licensor MAKES NO
 * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
 * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
 * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
 * OR OTHER RIGHTS.
 * 
 * Additional copyrights may follow.
 * 
 *	Ohio Trollius
 *	Copyright 1996 The Ohio State University
 *	RBD
 *
 *	$Id: getprocname.c,v 6.3 1999/12/31 21:27:25 jsquyres Exp $
 *
 *	Function:	- get the host name
 *	Accepts:	- name buffer (returned value)
 *			- ptr name length (returned value)
 *	Returns:	- MPI_SUCCESS or error code
 */

#include <string.h>

#include <blktype.h>
#include <mpi.h>
#include <mpisys.h>
#include <terror.h>

extern int		gethostname();


/*@
  MPI_Get_processor_name - Gets the name of the processor

Output Parameters:
+ name - A unique specifier for the actual (as opposed to virtual) node. 
- len - Length (in characters) of the name 

Notes:

LAM/MPI returns the value from 'gethostname'(3).

.N fortran

.N Errors
.N MPI_ERR_OTHER

.N ACK
@*/
int MPI_Get_processor_name(char *name, int *len)
{
	lam_initerr();
	lam_setfunc(BLKMPIGETPNAME);

	if (gethostname(name, MPI_MAX_PROCESSOR_NAME - 1)) {
		return(lam_errfunc(MPI_COMM_WORLD, BLKMPIGETPNAME,
				lam_mkerr(MPI_ERR_OTHER, errno)));
	} else {
		name[MPI_MAX_PROCESSOR_NAME - 1] = '\0';
		*len = strlen(name);
	}

	lam_resetfunc(BLKMPIGETPNAME);
	return(MPI_SUCCESS);
}
